@@ -1,4 +1,4 @@
-from nidaqmx.errors import DaqError, DaqWarning, DaqResourceWarning
+from nidaqmx.errors import DaqError, DaqReadError, DaqWriteError, DaqWarning, DaqResourceWarning
 from nidaqmx.scale import Scale
 from nidaqmx.task import Task
 from nidaqmx._task_modules.read_functions import CtrFreq, CtrTick, CtrTime
